<?php
/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://https://codecanyon.net/search/kamleshyadav
 * @since      1.0.0
 *
 * @package    Image_Buzz
 * @subpackage Image_Buzz/includes
 */
 
/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Image_Buzz
 * @subpackage Image_Buzz/includes
 * @author     kamleshyadav <admin@pixelnx.com>
 */
class Image_Buzz {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Image_Buzz_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if(defined('IMAGE_BUZZ_VERSION') ) {
			$this->version = IMAGE_BUZZ_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'image-buzz ';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Image_Buzz_Loader. Orchestrates the hooks of the plugin.
	 * - Image_Buzz_i18n. Defines internationalization functionality.
	 * - Image_Buzz_Admin. Defines all hooks for the admin area.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/image-buzz-class-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/image-buzz-class-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/image-buzz-class-admin.php';

		$this->loader = new Image_Buzz_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Image_Buzz_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Image_Buzz_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Image_Buzz_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');

		/**
		 * Elementor Editor Add Js
		 */
		$this->loader->add_action( 'elementor/editor/after_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
		$this->loader->add_action( 'elementor/editor/before_enqueue_styles', $plugin_admin, 'enqueue_styles');
		
		/**
		 * Add Menu in Dashboard 
		 */ 
		$this->loader->add_action('admin_menu', $plugin_admin, 'image_buzz_admin_menus');
		
		/**
		 *Image Buzz Add Media In Image Loading Ajax
		 */ 
		$this->loader->add_action('wp_ajax_nopriv_image_buzz_api_images', $plugin_admin, 'image_buzz_api_images');
		$this->loader->add_action('wp_ajax_image_buzz_api_images', $plugin_admin, 'image_buzz_api_images');
		/**
		 *Image Buzz Load More Ajax
		 */ 
		$this->loader->add_action( 'wp_ajax_nopriv_image_buzz_button_images_load', $plugin_admin, 'image_buzz_button_images_load');
		$this->loader->add_action('wp_ajax_image_buzz_button_images_load', $plugin_admin, 'image_buzz_button_images_load');

		/**
		 * Image Buzz Api Save
		 */
		$this->loader->add_action( 'wp_ajax_nopriv_image_buzz_pixabay_api_save', $plugin_admin, 'image_buzz_pixabay_api_save');
		$this->loader->add_action('wp_ajax_image_buzz_pixabay_api_save', $plugin_admin, 'image_buzz_pixabay_api_save');

		$this->loader->add_action( 'wp_ajax_nopriv_image_buzz_unsplash_api_save', $plugin_admin, 'image_buzz_unsplash_api_save');
		$this->loader->add_action('wp_ajax_image_buzz_unsplash_api_save', $plugin_admin, 'image_buzz_unsplash_api_save');

		$this->loader->add_action( 'wp_ajax_nopriv_image_buzz_pixels_api_save', $plugin_admin, 'image_buzz_pixels_api_save');
		$this->loader->add_action('wp_ajax_image_buzz_pixels_api_save', $plugin_admin, 'image_buzz_pixels_api_save');
		
		$this->loader->add_action( 'wp_ajax_nopriv_image_buzz_openai_api_save', $plugin_admin, 'image_buzz_openai_api_save');
		$this->loader->add_action('wp_ajax_image_buzz_openai_api_save', $plugin_admin, 'image_buzz_openai_api_save');

		$this->loader->add_action( 'wp_ajax_nopriv_imagebuzz_youtube_save', $plugin_admin, 'imagebuzz_youtube_save');
		$this->loader->add_action('wp_ajax_imagebuzz_youtube_save', $plugin_admin, 'imagebuzz_youtube_save');

		/**
		 * Click Image Save Media Libary
		 */
		$this->loader->add_action( 'wp_ajax_nopriv_image_buzz_upload_save_media', $plugin_admin, 'image_buzz_upload_save_media');
		$this->loader->add_action('wp_ajax_image_buzz_upload_save_media', $plugin_admin, 'image_buzz_upload_save_media');  

		$this->loader->add_action( 'wp_ajax_nopriv_image_buzz_api_clear', $plugin_admin, 'image_buzz_api_clear');
		$this->loader->add_action('wp_ajax_image_buzz_api_clear', $plugin_admin, 'image_buzz_api_clear');  

		/**
	     *  Videos Filter 
	     */ 
		$this->loader->add_action('wp_ajax_nopriv_image_buzz_videos_filters',$plugin_admin,'image_buzz_videos_filters');
		$this->loader->add_action('wp_ajax_image_buzz_videos_filters',$plugin_admin,'image_buzz_videos_filters'); 
		
		/**
	     * Yt Container Videos Text Save in Post
         */
		$this->loader->add_action('wp_ajax_nopriv_image_buzz_videos_saveinpost',$plugin_admin,'image_buzz_videos_saveinpost');
		$this->loader->add_action('wp_ajax_image_buzz_videos_saveinpost',$plugin_admin,'image_buzz_videos_saveinpost'); 
          
	}  
    
	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Image_Buzz_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

} 